package net.sourceforge.jpcap.util;

import java.util.Calendar;

/**
 * Common class to convert from one base type to another.
 * @author rwall
 *
 */
public class Convert {
	private static final int BYTE_MASK = 0xFF;

	private static final int HEX_WIDTH = 16;

	/**
	 * Represents a series of bytes as ASCII.
	 * 
	 * @param bytes
	 * @return
	 *//*
	public static String bytesToASCII(byte[] bytes) {
		if (bytes == null || bytes.length < 1)
			return null;
		StringBuffer sb = new StringBuffer();
		int t = (int) bytes[0];
		sb.append(t);
		return sb.toString();
	}
	*/
	
	/**
	 * Represents a series of bytes as hex.
	 * 
	 * @param bytes
	 * @return String
	 */
	public static String bytesToHex(byte[] bytes) {
		return bytesToHex(bytes, true); 
	}
	
	public static String bytesToHex(byte[] bytes, boolean spaceSeperated) {
		if (bytes == null || bytes.length < 1)
			return null;

		StringBuffer sb = new StringBuffer(bytes.length * 6);
		for (int i = 0; i < bytes.length; i += HEX_WIDTH) {
			for (int j = 0; j < HEX_WIDTH; j++) {
				if (i + j >= bytes.length) {
					if (bytes.length > HEX_WIDTH) {
						sb.append("   ");
					}
					continue;
				}
				String s = Integer.toHexString(bytes[i + j] & BYTE_MASK);
				if (s.length() < 2) {
					sb.append('0');
				}
				sb.append(s);
				if (spaceSeperated)
					sb.append(' ');
			}		
		}
		return sb.toString();
	}

	public static String bytesToHexDump(byte[] bytes) {
		return bytesToHexDump(bytes, bytes.length);
	}
	
	public static String bytesToHexDump(byte[] bytes, int numOfBytes) {
		if (bytes == null || bytes.length < 1)
			return null;

		StringBuffer sb = new StringBuffer(numOfBytes * 6);
		for (int i = 0; i < numOfBytes; i += HEX_WIDTH) {
			for (int j = 0; j < HEX_WIDTH; j++) {
				if (i + j >= numOfBytes) {
					if (numOfBytes > HEX_WIDTH) {
						sb.append("   ");
					}
					continue;
				}
				String s = Integer.toHexString(bytes[i + j] & BYTE_MASK);
				if (s.length() < 2) {
					sb.append('0');
				}
				sb.append(s);
				sb.append(' ');
			}

			for (int j = 0; j < HEX_WIDTH; j++) {
				if (i + j >= numOfBytes) {
					if (numOfBytes > HEX_WIDTH) {
						sb.append(' ');
					}
					continue;
				}
				char ch = (char) (bytes[i + j] & BYTE_MASK);
				if (ch >= ' ' && ch < 127) {
					sb.append(ch);
				} else {
					sb.append('.');
				}
			}
			sb.append('\n');
		}
		return sb.toString();
	}
	
	/**
	 * This assumes that each String element is an integer of size byte.
	 * 
	 * @param string
	 * @return byte[]
	 */
	public static byte[] stringArrayToBytes(String[] string) {
		byte[] bytes = new byte[string.length];
		for (int x = 0; x < string.length; x++) {
			bytes[x] = Integer.valueOf(string[x].trim()).byteValue();
		}
		return bytes;
	}

	/**
	 * Convert hex MAC address to dec.
	 * 
	 * @param string
	 * @return byte[]
	 */
	public static byte[] hexToDec(String[] string) {
		byte[] bytes = new byte[string.length];
		for (int x = 0; x < string.length; x++) {
			bytes[x] = Integer.valueOf(string[x].trim(), 16).byteValue();
		}
		return bytes;
	}

	/**
	 * Convert a Mac address as a string into an array of bytes.
	 * 
	 * @param mac
	 * @return byte[] or null if conversion fails
	 */
	public static byte[] macToBytes(String mac) {
		String[] temp = mac.split("-");
		if (temp.length != 6) {
			temp = mac.split(":");
			if (temp.length != 6)
				return null;
		}
		return hexToDec(temp);
	}

	/**
	 * Convert a Mac as an long into string.
	 * 
	 * @param ip
	 * @return
	 */
	public static String macToString(long mac) {
		return macToString(macToBytes(mac));
	}

	public static byte[] portToBytes(int port) {
		int firstByte = port >> 8;
		int secondByte = port & 0xFF; // mask everything out except the last
		// byte
		return new byte[] { Integer.valueOf(firstByte).byteValue(),
				Integer.valueOf(secondByte).byteValue() };
	}

	/**
	 * Converts a mas as a long to bytes
	 * 
	 * @param long
	 * @return bytes
	 */
	public static byte[] macToBytes(long mac) {
		return new byte[] { (byte) (0xff & (mac >> 40)),
				(byte) (0xff & (mac >> 32)), (byte) (0xff & (mac >> 24)),
				(byte) (0xff & (mac >> 16)), (byte) (0xff & (mac >> 8)),
				(byte) (0xff & mac) };
	}

	/**
	 * Convert a Mac address as a byte array to a string.
	 * 
	 * @param mac
	 * @return String or null if conversion fails
	 */
	public static String macToString(byte[] mac) {
		if (mac == null | mac.length < 1)
			return null;

		StringBuffer sb = new StringBuffer(mac.length * 6);
		for (int i = 0; i < mac.length; i++) {
			if (i != 0)
				sb.append(':');
			String s = Integer.toHexString(mac[i] & BYTE_MASK);
			if (s.length() < 2) {
				sb.append('0');
			}
			sb.append(s);

		}

		return sb.toString();
	}

	/**
	 * Converts a raw IP in bytes to a String representation
	 * 
	 * @param ip
	 * @return IP as a String
	 */
	public static String ipToString(byte[] ip) {
		try {
			return String.format("%d.%d.%d.%d", (int) ip[0] & 0xff,
					(int) ip[1] & 0xff, (int) ip[2] & 0xff, (int) ip[3] & 0xff);
		} catch (Exception E) {
			E.printStackTrace();
		}
		return null;
	}

	/**
	 * Converts an IP as a String into bytes.
	 * 
	 * @param ip
	 * @return
	 */
	public static byte[] ipToBytes(String ip) {
		try {
			String[] s = ip.split("\\.");
			byte[] b = new byte[4];
			for (int i = 0; i < 4; i++)
				b[i] = (byte) Integer.parseInt(s[i]);
			return b;
		} catch (Exception E) {
			E.printStackTrace();
		}
		return null;
	}

	/**
	 * Converts an IP as String to an integer
	 * 
	 * @param ip
	 * @return
	 */
	public static int ipToInt(String ip) {
		//return ipToString(intToBytes(ip));
			
		byte[] bytes = ipToBytes(ip);
		return bytesToInt(bytes);
	}
	/**
	 * Converts an IP as an integer into string.
	 * 
	 * @param ip
	 * @return
	 */
	public static String ipToString(int ip) {
		return ipToString(intToBytes(ip));
	}

	/**
	 * Converts a Long in to bytes
	 * 
	 * @param long
	 * @return bytes
	 */
	public static byte[] longToBytes(long longVal) {
		return new byte[] { (byte) (0xff & (longVal >> 56)),
				(byte) (0xff & (longVal >> 48)),
				(byte) (0xff & (longVal >> 40)),
				(byte) (0xff & (longVal >> 32)),
				(byte) (0xff & (longVal >> 24)),
				(byte) (0xff & (longVal >> 16)),
				(byte) (0xff & (longVal >> 8)), (byte) (0xff & longVal) };
	}

	/**
	 * Converts a four byte array into a long.
	 * 
	 * @param bytes
	 * @return int
	 */
	public static long bytesToLong(byte[] longVal) {
		if (longVal.length != 8)
			return 0;

		if (longVal == null || longVal.length != 8)
			return -1;

		return ((((long) longVal[0]) & 0xff) << 56)
				| ((((long) longVal[1]) & 0xff) << 48)
				| ((((long) longVal[2]) & 0xff) << 40)
				| ((((long) longVal[3]) & 0xff) << 32)
				| ((((long) longVal[4]) & 0xff) << 24)
				| ((((long) longVal[5]) & 0xff) << 16)
				| ((((long) longVal[6]) & 0xff) << 8)
				| ((((long) longVal[7]) & 0xff) << 0);
	}

	/**
	 * 
	 * @param i
	 * @return
	 */
	public static byte[] shortToBytes(int i) {
		return new byte[] { (byte) (0xff & (i >> 8)), (byte) (0xff & (i >> 0)) };
	}

	/**
	 * 
	 * @param i
	 * @return
	 */
	public static byte[] intToBytes(int i) {
		return new byte[] { (byte) (0xff & (i >> 24)),
				(byte) (0xff & (i >> 16)), (byte) (0xff & (i >> 8)),
				(byte) (0xff & (i >> 0)) };
	}

	/**
	 * 
	 * @param b
	 * @return
	 */
	public static int bytesToInt(byte[] b) {
		if (b.length != 4)
			return 0;
		return ((b[0] & 0xFF) << 24) | ((b[1] & 0xFF) << 16)
				| ((b[2] & 0xFF) << 8) | ((b[3] & 0xFF) << 0);
	}

	/**
	 * 
	 * @param b
	 * @return
	 */
	public static int bytesToShort(byte[] b) {
		if (b.length != 2)
			return 0;
		return ((b[0] & 0xFF) << 8) | ((b[1] & 0xFF) << 0);
	}

	/**
	 * 
	 * @param i
	 * @return
	 */
	public static int endian(int i) {
		return ((i << 24) & 0xFF000000) + ((i << 8) & 0xFF0000)
				+ ((i >> 8) & 0xFF00) + ((i >> 24) & 0xFF);
	}

	/**
	 * 
	 * @param time
	 * @return
	 */
	public static String longToDateString(long time) {
		Calendar e = Calendar.getInstance();
		e.setTimeInMillis(time);
		return (e.getTime().toString());
	}
}
